@@ -265,7 +265,7 @@ class PSMTemplate():
 
         # Adjust font size such that minimum padding is 0.1 cm
         title_block_font_size = self.get_font_size_from_max_width([client,project,location,description_line_1,description_line_2],"Arial",self.title_block_font_size,(self.title_block_width-0.2)*cm)
-
+        
         canvas.setFont("Arial",title_block_font_size)
         client_text_width = stringWidth(client,"Arial",title_block_font_size)
         canvas.drawString((self.page_width-self.padding.right-self.padding.left-0.5*self.title_block_width)*cm-0.5*client_text_width,(self.divider_height+(self.title_block_height-self.divider_height)/5*4+0.1)*cm,client)
@@ -279,7 +279,7 @@ class PSMTemplate():
         canvas.drawString((self.page_width-self.padding.right-self.padding.left-0.5*self.title_block_width)*cm-0.5*description_line_2_width,self.divider_height*cm+0.1*cm,description_line_2)
         
         # Add doc number and page number
-        title_block_font_size = self.get_font_size_from_max_width([doc_no,page_no],"Arial",title_block_font_size,(0.5*self.title_block_width-0.2)*cm)
+        title_block_font_size = self.get_font_size_from_max_width([doc_no,page_no],"Arial",self.title_block_font_size,(0.5*self.title_block_width-0.2)*cm)
         doc_no_text_width = stringWidth(doc_no,"Arial",title_block_font_size)
         canvas.drawString((self.page_width-self.padding.right-self.padding.left-0.75*self.title_block_width)*cm-0.5*doc_no_text_width,0.1*cm,doc_no)
         page_no_text_width = stringWidth(page_no,"Arial",title_block_font_size)
